@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -161,7 +161,11 @@ pd_update_general_tab (EomPropertiesDialog *prop_dlg,
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->type_label), type_str);
 
 	bytes = eom_image_get_bytes (image);
+#if GLIB_CHECK_VERSION (2, 30, 0)
+	bytes_str = g_format_size (bytes);
+#else
 	bytes_str = g_format_size_for_display (bytes);
+#endif
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->bytes_label), bytes_str);
 
@@ -491,8 +495,8 @@ pd_close_button_clicked_cb (GtkButton *button,
 
 static gboolean
 eom_properties_dialog_page_switch (GtkNotebook     *notebook,
-				   GtkNotebookPage *page,
-				   gint             page_index,
+				   gpointer         page,
+				   guint            page_index,
 				   EomPropertiesDialog *prop_dlg)
 {
 
