@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -345,7 +345,11 @@ thumbview_get_tooltip_string (EomImage *image)
 	ExifData *exif_data;
 #endif
 
+#if GLIB_CHECK_VERSION (2, 30, 0)
+	bytes = g_format_size (eom_image_get_bytes (image));
+#else
 	bytes = g_format_size_for_display (eom_image_get_bytes (image));
+#endif
 
 	eom_image_get_size (image, &width, &height);
 
